#[non_exhaustive]pub struct AggregateUsageRequest {
pub name: String,
pub page_size: i32,
pub page_token: String,
pub filter: String,
pub order_by: String,
pub start_time: Option<Timestamp>,
pub end_time: Option<Timestamp>,
/* private fields */
}Expand description
Message for requesting aggregate of Usage per configuration.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. Parent value for AggregateUsageRequest
page_size: i32Optional. Requested page size. Server may return fewer items than requested. If unspecified, server will pick an appropriate default.
page_token: StringOptional. A token identifying a page of results the server should return.
filter: StringOptional. Filtering results
order_by: StringOptional. Hint for how to order the results
start_time: Option<Timestamp>Required. Licenses are purchased per month - so usage track needs start time of a month.
end_time: Option<Timestamp>Required. Usage track is always for a month. This parameter is for the end time of the month.
Implementations
Sourceimpl AggregateUsageRequest
impl AggregateUsageRequest
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
ⓘ
let x = AggregateUsageRequest::new().set_page_token("example");Sourcepub fn set_filter<T: Into<String>>(self, v: T) -> Self
pub fn set_filter<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_order_by<T: Into<String>>(self, v: T) -> Self
pub fn set_order_by<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_start_time<T>(self, v: T) -> Self
pub fn set_start_time<T>(self, v: T) -> Self
Sets the value of start_time.
Example
ⓘ
use wkt::Timestamp;
let x = AggregateUsageRequest::new().set_start_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_start_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_start_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of start_time.
Example
ⓘ
use wkt::Timestamp;
let x = AggregateUsageRequest::new().set_or_clear_start_time(Some(Timestamp::default()/* use setters */));
let x = AggregateUsageRequest::new().set_or_clear_start_time(None::<Timestamp>);Sourcepub fn set_end_time<T>(self, v: T) -> Self
pub fn set_end_time<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_end_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_end_time<T>(self, v: Option<T>) -> Self