#[non_exhaustive]pub struct CreateConfigurationRequest {
pub parent: String,
pub configuration_id: String,
pub configuration: Option<Configuration>,
pub request_id: String,
/* private fields */
}Expand description
Message for creating a Configuration
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. Value for parent.
configuration_id: StringRequired. Id of the requesting object
configuration: Option<Configuration>Required. The resource being created
request_id: StringOptional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
Implementations
Sourceimpl CreateConfigurationRequest
impl CreateConfigurationRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_configuration_id<T: Into<String>>(self, v: T) -> Self
pub fn set_configuration_id<T: Into<String>>(self, v: T) -> Self
Sets the value of configuration_id.
Example
let x = CreateConfigurationRequest::new().set_configuration_id("example");Sourcepub fn set_configuration<T>(self, v: T) -> Selfwhere
T: Into<Configuration>,
pub fn set_configuration<T>(self, v: T) -> Selfwhere
T: Into<Configuration>,
Sets the value of configuration.
Example
use google_cloud_licensemanager_v1::model::Configuration;
let x = CreateConfigurationRequest::new().set_configuration(Configuration::default()/* use setters */);Sourcepub fn set_or_clear_configuration<T>(self, v: Option<T>) -> Selfwhere
T: Into<Configuration>,
pub fn set_or_clear_configuration<T>(self, v: Option<T>) -> Selfwhere
T: Into<Configuration>,
Sets or clears the value of configuration.
Example
use google_cloud_licensemanager_v1::model::Configuration;
let x = CreateConfigurationRequest::new().set_or_clear_configuration(Some(Configuration::default()/* use setters */));
let x = CreateConfigurationRequest::new().set_or_clear_configuration(None::<Configuration>);Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = CreateConfigurationRequest::new().set_request_id("example");Trait Implementations
Sourceimpl Clone for CreateConfigurationRequest
impl Clone for CreateConfigurationRequest
Sourcefn clone(&self) -> CreateConfigurationRequest
fn clone(&self) -> CreateConfigurationRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for CreateConfigurationRequest
impl Debug for CreateConfigurationRequest
Sourceimpl Default for CreateConfigurationRequest
impl Default for CreateConfigurationRequest
Sourcefn default() -> CreateConfigurationRequest
fn default() -> CreateConfigurationRequest
Sourceimpl Message for CreateConfigurationRequest
impl Message for CreateConfigurationRequest
Sourceimpl PartialEq for CreateConfigurationRequest
impl PartialEq for CreateConfigurationRequest
Sourcefn eq(&self, other: &CreateConfigurationRequest) -> bool
fn eq(&self, other: &CreateConfigurationRequest) -> bool
self and other values to be equal, and is used by ==.