#[non_exhaustive]pub struct QueryConfigurationLicenseUsageRequest {
pub name: String,
pub start_time: Option<Timestamp>,
pub end_time: Option<Timestamp>,
/* private fields */
}Expand description
Message for requesting license usage per configuration.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. The resource path of the Configuration.
start_time: Option<Timestamp>Required. The start time for retrieving the usage. If not specified, we will use the first day of the current billing period.
end_time: Option<Timestamp>Required. The end time for retrieving the usage. If not specified, we will use the last day of the current billing period.
Implementations
Sourceimpl QueryConfigurationLicenseUsageRequest
impl QueryConfigurationLicenseUsageRequest
Sourcepub fn set_start_time<T>(self, v: T) -> Self
pub fn set_start_time<T>(self, v: T) -> Self
Sets the value of start_time.
Example
ⓘ
use wkt::Timestamp;
let x = QueryConfigurationLicenseUsageRequest::new().set_start_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_start_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_start_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of start_time.
Example
ⓘ
use wkt::Timestamp;
let x = QueryConfigurationLicenseUsageRequest::new().set_or_clear_start_time(Some(Timestamp::default()/* use setters */));
let x = QueryConfigurationLicenseUsageRequest::new().set_or_clear_start_time(None::<Timestamp>);Sourcepub fn set_end_time<T>(self, v: T) -> Self
pub fn set_end_time<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_end_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_end_time<T>(self, v: Option<T>) -> Self