#[non_exhaustive]pub struct QueryConfigurationLicenseUsageResponse {
pub details: Option<Details>,
/* private fields */
}Expand description
Message for response to get the license usage per configuration.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.details: Option<Details>Depending on the type of the configuration, one of the following will be populated.
Implementations
Sourceimpl QueryConfigurationLicenseUsageResponse
impl QueryConfigurationLicenseUsageResponse
Sourcepub fn set_details<T: Into<Option<Details>>>(self, v: T) -> Self
pub fn set_details<T: Into<Option<Details>>>(self, v: T) -> Self
Sets the value of details.
Note that all the setters affecting details are mutually
exclusive.
Example
ⓘ
use google_cloud_licensemanager_v1::model::UserCountUsage;
let x = QueryConfigurationLicenseUsageResponse::new().set_details(Some(
google_cloud_licensemanager_v1::model::query_configuration_license_usage_response::Details::UserCountUsage(UserCountUsage::default().into())));Sourcepub fn user_count_usage(&self) -> Option<&Box<UserCountUsage>>
pub fn user_count_usage(&self) -> Option<&Box<UserCountUsage>>
The value of details
if it holds a UserCountUsage, None if the field is not set or
holds a different branch.
Sourcepub fn set_user_count_usage<T: Into<Box<UserCountUsage>>>(self, v: T) -> Self
pub fn set_user_count_usage<T: Into<Box<UserCountUsage>>>(self, v: T) -> Self
Sets the value of details
to hold a UserCountUsage.
Note that all the setters affecting details are
mutually exclusive.
Example
ⓘ
use google_cloud_licensemanager_v1::model::UserCountUsage;
let x = QueryConfigurationLicenseUsageResponse::new().set_user_count_usage(UserCountUsage::default()/* use setters */);
assert!(x.user_count_usage().is_some());Trait Implementations
Sourceimpl Clone for QueryConfigurationLicenseUsageResponse
impl Clone for QueryConfigurationLicenseUsageResponse
Sourcefn clone(&self) -> QueryConfigurationLicenseUsageResponse
fn clone(&self) -> QueryConfigurationLicenseUsageResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for QueryConfigurationLicenseUsageResponse
impl Default for QueryConfigurationLicenseUsageResponse
Sourcefn default() -> QueryConfigurationLicenseUsageResponse
fn default() -> QueryConfigurationLicenseUsageResponse
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for QueryConfigurationLicenseUsageResponse
impl PartialEq for QueryConfigurationLicenseUsageResponse
Sourcefn eq(&self, other: &QueryConfigurationLicenseUsageResponse) -> bool
fn eq(&self, other: &QueryConfigurationLicenseUsageResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for QueryConfigurationLicenseUsageResponse