#[non_exhaustive]pub struct UserCountUsage {
pub unique_user_count: i32,
/* private fields */
}Expand description
Message representing usage for license configurations which use user-count billing.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.unique_user_count: i32Required. Unique number of licensed users.
Implementations
Sourceimpl UserCountUsage
impl UserCountUsage
Sourcepub fn set_unique_user_count<T: Into<i32>>(self, v: T) -> Self
pub fn set_unique_user_count<T: Into<i32>>(self, v: T) -> Self
Sets the value of unique_user_count.
Example
ⓘ
let x = UserCountUsage::new().set_unique_user_count(42);Trait Implementations
Sourceimpl Clone for UserCountUsage
impl Clone for UserCountUsage
Sourcefn clone(&self) -> UserCountUsage
fn clone(&self) -> UserCountUsage
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UserCountUsage
impl Debug for UserCountUsage
Sourceimpl Default for UserCountUsage
impl Default for UserCountUsage
Sourcefn default() -> UserCountUsage
fn default() -> UserCountUsage
Returns the “default value” for a type. Read more
Sourceimpl Message for UserCountUsage
impl Message for UserCountUsage
Sourceimpl PartialEq for UserCountUsage
impl PartialEq for UserCountUsage
Sourcefn eq(&self, other: &UserCountUsage) -> bool
fn eq(&self, other: &UserCountUsage) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for UserCountUsage